import * as React from 'react';

import Default from './components/Default';
import Info from './components/Info';
import BigAttention from './components/BigAttention';
import Attention from './components/Attention';
import Warning from './components/Warning';
import Refused from './components/Refused';
import Accepted from './components/Accepted';
import Custom from './components/Custom';

export interface IProps {
  children?: React.ReactNode|React.ReactChild;
  text?: string;
  icon?: string;
  variation?: 'default'|'info'|'big-attention'|'attention'|'warning'|'refused'|'accepted'|'custom';
  onClose?: (isActive?: boolean) => void;
  active: boolean;
  color?: string;
}

const alertsFlagsComponentsMap = new Map()
  .set('default', (props: IProps) => <Default {...props} />)
  .set('info', (props: IProps) => <Info {...props} />)
  .set('big-attention', (props: IProps) => <BigAttention {...props} />)
  .set('attention', (props: IProps) => <Attention {...props} />)
  .set('warning', (props: IProps) => <Warning {...props} />)
  .set('refused', (props: IProps) => <Refused {...props} />)
  .set('accepted', (props: IProps) => <Accepted {...props} />)
  .set('custom', (props: IProps) => <Custom {...props} />);

export default ({ variation, ...props }: IProps) => alertsFlagsComponentsMap
  .get(variation || 'default')(props) || null;
