import styled from 'styled-components';

import Sizes from '../Sizes';
import Colors from '../Colors';
import TextHelper from '../TextHelper';
import { styledByMediaQuery } from '../utils/styles';

export const ColorPicker = styled.div`
  background-color: white;
  border: 1px solid ${Colors.line};
  position: relative;
  width: 100%;
  margin-bottom: ${Sizes.s4}px;
  ${styledByMediaQuery(`width: 308px;`)}

  &:before {
    content: '';
    position: absolute;
    top: 128px;
    left: 50%;
    margin-left: -6px;
    border-left: 10px solid transparent;
    border-right: 10px solid transparent;
    border-bottom: 12px solid white;
  }
`;

export const BoxColor = styled.div<{color: string}>`
  height: 140px;
  background-color: ${({ color }) => color};
  transition: 0.6s;
  color: white;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: ${Sizes.s4}px;
`;

export const GridColors = styled.div`
  padding: ${Sizes.s3}px ${Sizes.s5}px;
  display: grid;
  grid-template-columns: repeat(5, 31px);
  grid-row-gap: ${Sizes.s3}px;
  justify-content: space-between;
`;

export const ColumnColor = styled.button.attrs({
  type: 'button',
})<{color: string}>`
  width: 31px;
  height: 31px;
  background-color: ${({ color }) => color};
  border: 0 none;
  cursor: pointer;
`;

export const InputColor = styled.div`
  background-color: ${Colors.heaven};
  width: 130px;
  margin: 0 auto ${Sizes.s3}px;
  padding: ${Sizes.s2}px;

  .input {
    width: 100%;
    color: ${Colors.codGray};
    border: 0 none;
    border-bottom: 1px solid;
    background-color: inherit;
    outline: 0 none;
    font-family: ${TextHelper.fontVariant('medium')};
  }
`;

export const Check = styled.div`
  display: inline-block;
  &:after {
    content: '';
    display: block;
    width: 12px;
    height: 24px;
    border: solid white;
    border-width: 0 2px 2px 0;
    transform: rotate(45deg);
  }
`;
