import styled from 'styled-components';

import Colors from '../Colors';
import TextHelper from '../TextHelper';
import Sizes from '../Sizes';

export const WrapperTable = styled.table`
  width: 100%;
  text-align: center;
  border-collapse: collapse;

  @media screen and (min-width: 768px) {
    width: 376px;
    margin: 25px auto 0;
  }
`;

export const DaysRow = styled.tr`
  color: ${Colors.support};
  font-size: ${TextHelper.pxToEm(Sizes.s3)}em;
`;

export const DaysColumn = styled.td<{ active: boolean }>`

  button {
    background-color: transparent;
    border: 0;
    border-radius: 50%;
    width: 41px;
    height: 41px;
    margin: 5px auto;
    display: flex;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    transition: .5s all ease;
    font-size: ${TextHelper.pxToEm(Sizes.s3)}em;
    font-family: ${TextHelper.fontVariant('regular')};
  }

  ${({ active }) => active && `
    button {
      background-color: ${Colors.mongeral};
      color: white;
    }
  `};
`;

export const SelectYear = styled.select`
  appearance: none;
  border: 0 none;
  background-color: transparent;
  font-size: 16px;
  font-family: ${TextHelper.fontVariant('medium')};
  text-transform: uppercase;
  width: 100%;
  max-width: 90%;
`;

export const SelectYearWrapper = styled.div`
  text-align: center;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  margin: 25px 0 25px 15px;

  @media screen and (min-width: 768px) {
    margin: 41px 0 10px 67px;
  }
  
  &:last-of-type {
    margin-left: 20px
  }

  label {
    display: inherit;
  }

  svg {
    margin-left: 5px;
  }
`;

export const InputWrapper = styled.div`
  position: relative;

  button {
    appearance: none;
    background-color: transparent;
    border: 0 none;
    padding: 0;
    position: absolute;
    top: -3px;
    right: 0;
  }
`;

export const ModalStyles = styled.div`

  div[type="default"] { padding: 0 0 20px }

  .close { right: 20px; background-color: transparent; top: 16px; position: absolute }

  @media screen and (min-width: 768px) {
    div[type="default"] {
      padding: 0;
      max-height: 494px;
      margin-top: 109px;
    };
    

    & .footer-modal {
      position: absolute;
      bottom: 20px;
      right: 20px;
    }
  }
`;
