import * as React from 'react';
import * as ReactDOM from 'react-dom';

import { ModalStyle, Close, WrapperButton, Overlay, Wrapper, WrapperClose } from './Modal.styled';
import { Button, Icons } from '../index';

interface IProps {
  active: boolean;
  type?: string;
  onClose: (boolean: boolean) => void;
  onConfirm?: any;
  onConfirmText?: string;
  selector: string;
  css?: string;
  asyncClose?: (e?: Function) => void;
  onConfirmType?: string;
}

export default class Modal extends React.PureComponent<IProps> {
  el: HTMLElement | Node | null;
  html: HTMLElement;
  body: HTMLBodyElement;
  state = {
    animation: 'enter',
  };

  componentDidMount() {
    this.el = document.querySelector(this.props.selector);
    (this.body as any) = document.querySelector('body');
    (this.html as any) = document.querySelector('html');
    this.props.asyncClose && this.props.asyncClose(this.onClose);
  }

  onClose = async () => {
    this.setState({ animation: 'leave' });
    setTimeout(() => {
      this.props.onClose(false);
      this.setState({ animation: 'enter' });
    }, 400);
  }

  externalStyles = (overflow: string, position: string) => {
    this.body.style.overflow = overflow;
    this.body.style.height = '100%';
    this.body.style.margin = '0';

    this.html.style.overflow = overflow;
    this.html.style.height = '100%';
    this.html.style.margin = '0';

    this.body.style.position = position;
  };

  componentDidUpdate(prevProps: Object, prevState: { animation: string }) {
    if (prevState.animation === 'enter') {
      this.externalStyles('hidden', 'relative');
    } else {
      this.externalStyles('auto', 'static');
    }
  }

  onConfirm = () => this.props.onConfirm ? this.props.onConfirm() : this.onClose();

  render () {
    const { active, children, type, onConfirm, onConfirmText, onConfirmType, ...props } = this.props;
    const isType = type || 'default';

    return active && ReactDOM.createPortal((
      <React.Fragment>
        { isType !== 'full' && <Overlay animation={this.state.animation} onClick={this.onClose} />}
        <ModalStyle animation={this.state.animation} type={isType} {...props}>
          <Wrapper>
            <WrapperClose className='close'>
              <Close type='button' onClick={this.onClose} isType={isType}>
                <Icons.Close width={27} height={27} />
              </Close>
            </WrapperClose>
            {children}
          </Wrapper>
          {
            isType !== 'small' && (
              <WrapperButton className='footer-modal'>
                <Button isType='link' type='button' onClick={this.onClose}>FECHAR</Button>
                {(onConfirm || onConfirmText) && <Button isType={onConfirmType || 'confirm'} type='button' onClick={this.onConfirm}>{onConfirmText || 'Salvar'}</Button>}
              </WrapperButton>
            )
          }
        </ModalStyle>
      </React.Fragment>
    ), (this.el as HTMLElement))
  }
}