import styled, { css, keyframes } from 'styled-components';

import { Sizes, TextHelper } from '../index';
import Colors from '../Colors';

export const Wrapper = styled.div`
  position: relative;

  svg {
    position: absolute;
    right: 0;
  }
`;

const bounceUp = keyframes`
  from { transform: scale3d(1, 1, 1); }
  50% { transform: scale3d(1.1618, 1.1618, 1.1618); }
  to { transform: scale3d(1, 1, 1); }
`;

const shake = keyframes`
  from, to { transform: translate3d(0, 0, 0); }
  10%, 30%, 50%, 70%, 90% { transform: translate3d(-3px, 0, 0); }
  20%, 40%, 60%, 80% { transform: translate3d(3px, 0, 0); }
`;

const bounceUpRule = css`${bounceUp} .4s forwards;`;

const shakeRule = (props: any) => css`${props.isInvalid && shake} 1s forwards;`;

const opacityAndTransition = (opacity: number, transition: string) => `
  opacity: ${opacity};
  transition: ${transition};
`;

const activatedLabel = () => `
  top: -16px;
  color: ${Colors.mongeral};
  z-index: 1; 
  ${opacityAndTransition(1, '0.3s')};
`;

export const SelectStyled = styled.select`
  font-family: ${TextHelper.fontVariant('medium')};
  font-weight: 500;
  color: ${Colors.codGray};
  width: 100%;
  box-sizing: border-box;
  letter-spacing: 1px;
  border: 0;
  padding: 4px 0;
  border-bottom: 1px solid currentColor;
  background-color: transparent;
  appearance: none;
  border-radius: 0;
  outline: none;

  &:focus {

    & + label {
      ${activatedLabel()}
      animation: ${bounceUpRule};
    }
  }
`;

export const Label = styled.label<{ active: boolean|string }>`
  position: absolute;
  font-size: ${TextHelper.pxToEm(Sizes.s2)}em;
  font-family: ${TextHelper.fontVariant('medium')};
  font-weight: 500;
  left: 0;
  top: -16px;
  z-index: -1;
  letter-spacing: 0.5px;
  ${opacityAndTransition(0, 'all .2s ease')};
  animation: ${shakeRule};
  text-transform: uppercase;
  opacity: 0;

  ${({ active }) => active && activatedLabel()}
`;